@@ -22,6 +22,8 @@ __all__ = [
     "dt_utc_infinity",
     "dt_utc_now",
     "dt_utc",
+    "td_to_us",
+    "td_from_us",
     "dt_to_ts",
     "dt_to_ts_us",
     "dt_from_ts",
@@ -35,11 +37,23 @@ __all__ = [
 
 @singleton
 def basic_date_format() -> str:
+    """
+    Returns the basic date format string.
+
+    :return: The basic date format string.
+    """
     return "%Y%m%d"
 
 
 @memorized
 def basic_time_format(with_ms: bool = False, with_tz: bool = False) -> str:
+    """
+    Returns the basic time format string, with optional milliseconds and timezone.
+
+    :param with_ms: If ``True``, include milliseconds in the format.
+    :param with_tz: If ``True``, include timezone in the format.
+    :return: The basic time format string.
+    """
     fmt_str = "T%H%M%S"
     if with_ms:
         fmt_str = fmt_str + ".%f"
@@ -50,16 +64,35 @@ def basic_time_format(with_ms: bool = False, with_tz: bool = False) -> str:
 
 @memorized
 def basic_format(with_ms: bool = False, with_tz: bool = False) -> str:
+    """
+    Returns the basic combined date and time format string, with optional milliseconds and timezone.
+
+    :param with_ms: If ``True``, include milliseconds in the time format.
+    :param with_tz: If ``True``, include timezone in the time format.
+    :return: The basic combined date and time format string.
+    """
     return basic_date_format() + basic_time_format(with_ms, with_tz)
 
 
 @singleton
 def extended_date_format() -> str:
+    """
+    Returns the extended date format string.
+
+    :return: The extended date format string.
+    """
     return "%Y-%m-%d"
 
 
 @memorized
 def extended_time_format(with_ms: bool = False, with_tz: bool = False) -> str:
+    """
+    Returns the extended time format string, with optional milliseconds and timezone.
+
+    :param with_ms: If ``True``, include milliseconds in the format.
+    :param with_tz: If ``True``, include timezone in the format.
+    :return: The extended time format string.
+    """
     fmt_str = "T%H:%M:%S"
     if with_ms:
         fmt_str = fmt_str + ".%f"
@@ -70,6 +103,13 @@ def extended_time_format(with_ms: bool = False, with_tz: bool = False) -> str:
 
 @memorized
 def extended_format(with_ms: bool = False, with_tz: bool = False) -> str:
+    """
+    Returns the extended combined date and time format string, with optional milliseconds and timezone.
+
+    :param with_ms: If ``True``, include milliseconds in the time format.
+    :param with_tz: If ``True``, include timezone in the time format.
+    :return: The extended combined date and time format string.
+    """
     return extended_date_format() + extended_time_format(with_ms, with_tz)
 
 
@@ -80,6 +120,12 @@ iso_format = extended_format
 
 @singleton
 def iso_formats() -> list[str]:
+    """
+    Returns a list of supported ISO 8601 date and time format strings, including both basic and extended forms, with
+    optional milliseconds and timezone.
+
+    :return: A list of ISO 8601 format strings.
+    """
     return [
         extended_format(True, False),
         extended_format(False, True),
@@ -109,11 +155,21 @@ def dt_utc_min() -> datetime.datetime:
 
 @singleton
 def dt_utc_max() -> datetime.datetime:
+    """
+    Returns the maximum representable UTC datetime.
+
+    :return: The maximum UTC datetime.
+    """
     return datetime.datetime.max.replace(tzinfo=datetime.timezone.utc)
 
 
 @singleton
 def dt_utc_epoch() -> datetime.datetime:
+    """
+    Returns the UTC datetime representing the POSIX epoch (1970-01-01T00:00:00Z).
+
+    :return: The UTC epoch datetime.
+    """
     return datetime.datetime(1970, 1, 1, 0, 0, 0, 0, tzinfo=datetime.timezone.utc)
 
 
@@ -122,9 +178,9 @@ dt_utc_infinity = dt_utc_max
 
 def dt_utc_now() -> datetime.datetime:
     """
-    Returns instance of current date time in UTC
+    Returns the current date and time in UTC.
 
-    :return: current date time in UTC
+    :return: The current UTC datetime.
     """
     return datetime.datetime.now(tz=datetime.timezone.utc)
 
@@ -139,86 +195,98 @@ def dt_utc(
     microsecond: int = 0
 ) -> datetime.datetime:
     """
-    Returns instance of the specified date time in UTC
+    Returns a UTC datetime instance for the specified date and time components.
 
-    :param year: year part
-    :param month: month part
-    :param day: day part
-    :param hour: hour part
-    :param minute: minute part
-    :param second: second part
-    :param microsecond: microsecond part
-
-    :return: specified date time in UTC
+    :param year: Year component.
+    :param month: Month component.
+    :param day: Day component.
+    :param hour: Hour component.
+    :param minute: Minute component.
+    :param second: Second component.
+    :param microsecond: Microsecond component.
+    :return: The specified UTC datetime.
     """
     return datetime.datetime(year, month, day, hour, minute, second, microsecond, tzinfo=datetime.timezone.utc)
 
 
+def td_to_us(td: datetime.timedelta) -> int:
+    """
+    Returns the total number of microseconds in the given ``timedelta``.
+
+    :param td: The ``timedelta`` to convert.
+    :return: The total number of microseconds in ``td``.
+    """
+    return (td.days * 86400 + td.seconds) * 1000000 + td.microseconds
+
+
+def td_from_us(us: int) -> datetime.timedelta:
+    """
+    Returns a ``timedelta`` representing the given number of microseconds.
+
+    :param us: The number of microseconds.
+    :return: The corresponding ``timedelta``.
+    """
+    return datetime.timedelta(microseconds=us)
+
+
 def dt_to_td(dt: datetime.datetime) -> datetime.timedelta:
     """
-    Returns corresponding timedelta of the given datetime
+    Returns the ``timedelta`` between the given ``datetime`` and the POSIX epoch.
 
-    :param dt: the given datetime
-
-    :return: timedelta from POSIX epoch
+    :param dt: The ``datetime`` to convert.
+    :return: The ``timedelta`` from the POSIX epoch to ``dt``.
     """
     return dt.replace(tzinfo=datetime.timezone.utc) - dt_utc_epoch()
 
 
 def dt_to_ts(dt: datetime.datetime) -> float:
     """
-    Returns corresponding timestamp in seconds of the given datetime
+    Returns the timestamp in seconds (as a float) for the given ``datetime`` since the POSIX epoch.
 
-    :param dt: the given datetime
-
-    :return: timestamp in seconds from POSIX epoch
+    :param dt: The ``datetime`` to convert.
+    :return: The timestamp in seconds from the POSIX epoch.
     """
     return dt_to_ts_us(dt) / 1.0e6
 
 
 def dt_to_ts_us(dt: datetime.datetime) -> int:
     """
-    Returns corresponding timestamp in microseconds of the given datetime
+    Returns the timestamp in microseconds (as an integer) for the given ``datetime`` since the POSIX epoch.
 
-    :param dt: the given datetime
-
-    :return: timestamp in microseconds from POSIX epoch
+    :param dt: The ``datetime`` to convert.
+    :return: The timestamp in microseconds from the POSIX epoch.
     """
-    td = dt_to_td(dt)
-    return (td.days * 86400 + td.seconds) * 1000000 + td.microseconds
+    return td_to_us(dt_to_td(dt))
 
 
 def dt_from_td(td: datetime.timedelta) -> datetime.datetime:
     """
-    Returns corresponding datetime in UTC of the given timedelta
+    Returns the UTC datetime corresponding to the given ``timedelta`` from the POSIX epoch.
 
-    :param td: timedelta from POSIX epoch
-
-    :return: the given datetime in UTC
+    :param td: The ``timedelta`` from the POSIX epoch.
+    :return: The corresponding UTC datetime.
     """
     return dt_utc_epoch() + td
 
 
 def dt_from_ts(ts: float) -> datetime.datetime:
     """
-    Returns corresponding datetime in UTC of the given timestamp in seconds
+    Returns the UTC datetime corresponding to the given timestamp in seconds from the POSIX epoch.
 
-    :param ts: timestamp in seconds from POSIX epoch
-
-    :return: the given datetime in UTC
+    :param ts: Timestamp in seconds from the POSIX epoch.
+    :return: The corresponding UTC datetime.
     """
     return dt_from_ts_us(round(ts * 1.0e6))
 
 
 def dt_from_ts_us(ts: int) -> datetime.datetime:
     """
-    Returns corresponding datetime in UTC of the given timestamp in microseconds
+    Returns the UTC datetime corresponding to the given timestamp in microseconds from the POSIX epoch.
 
-    :param ts: timestamp in microseconds from POSIX epoch
-
-    :return: the given datetime in UTC
+    :param ts: Timestamp in microseconds from the POSIX epoch.
+    :return: The corresponding UTC datetime.
     """
-    return dt_from_td(datetime.timedelta(microseconds=ts))
+    return dt_from_td(td_from_us(ts))
 
 
 basic_date_regex: re.Pattern[str] = re.compile(r"(\d{4})(\d{2})(\d{2})")
@@ -231,12 +299,13 @@ extended_tz_regexp: re.Pattern[str] = re.compile(r"([+-])(\d{2}):(\d{2})")
 
 def dt_parse(dt_str: str, fmt_str: str | Sequence[str]) -> datetime.datetime | None:
     """
-    Null safely parses given string value of a datetime to the datetime instance
+    Safely parses a string value representing a datetime into a ``datetime`` instance. Supports multiple format
+    candidates and handles ISO 8601 timezone formats.
 
-    :param dt_str: string value of the given datetime
-    :param fmt_str: format string, or a list/tuple of format string candidates
-
-    :return: datetime instance
+    :param dt_str: String value representing the datetime.
+    :param fmt_str: Format string, or a sequence of format string candidates.
+    :return: The parsed ``datetime`` instance, or ``None`` if input is ``None``.
+    :raises ValueError: If no format matches the input string.
     """
     if dt_str is None:
         return None
@@ -246,7 +315,7 @@ def dt_parse(dt_str: str, fmt_str: str | Sequence[str]) -> datetime.datetime | N
             if tz_directive in fmt_str:
                 if tz_directive == "%:z":
                     # Replaces ISO 8601 timezone format "%:z" (e.g., "+01:00") with "%z" (e.g., "+0100")
-                    # because `datetime.strptime` does not support "%:z".
+                    # because ``datetime.strptime`` does not support "%:z".
                     dt_str = extended_tz_regexp.sub(r"\1\2\3", dt_str)
                     fmt_str = fmt_str.replace("%:z", "%z")
                 return datetime.datetime.strptime(dt_str, fmt_str)
@@ -264,12 +333,12 @@ def dt_parse(dt_str: str, fmt_str: str | Sequence[str]) -> datetime.datetime | N
 
 def dt_format(dt: datetime.datetime, fmt_str: str) -> str | None:
     """
-    Null safely formats the given datetime to a string value
+    Safely formats a ``datetime`` instance as a string using the specified format. Handles ISO 8601 timezone formats and
+    supports years with fewer than four digits.
 
-    :param dt: the given datetime
-    :param fmt_str: format string
-
-    :return: string value of the given datetime
+    :param dt: The ``datetime`` instance to format.
+    :param fmt_str: The format string.
+    :return: The formatted string, or ``None`` if input is ``None``.
     """
     if dt is None or fmt_str is None:
         return None
@@ -282,7 +351,7 @@ def dt_format(dt: datetime.datetime, fmt_str: str) -> str | None:
         year_str = str(dt.year).zfill(2)
         fmt_str = fmt_str.replace("%y", year_str)
 
-    # Manually handles the "%:z" timezone directive, since `datetime.strftime`
+    # Manually handles the "%:z" timezone directive, since ``datetime.strftime``
     # does not support it before Python 3.12
     if sys.version_info < (3, 12):
         if "%:z" in fmt_str:
@@ -293,8 +362,20 @@ def dt_format(dt: datetime.datetime, fmt_str: str) -> str | None:
 
 
 def dt_parse_iso(dt_str: str) -> datetime.datetime | None:
+    """
+    Parses a string as an ISO 8601 datetime using all supported ISO format candidates.
+
+    :param dt_str: String value representing the datetime.
+    :return: The parsed ``datetime`` instance, or ``None`` if input is ``None``.
+    """
     return dt_parse(dt_str, iso_formats())
 
 
 def dt_format_iso(dt: datetime.datetime) -> str | None:
+    """
+    Formats a ``datetime`` instance as an ISO 8601 string using the default ISO format.
+
+    :param dt: The ``datetime`` instance to format.
+    :return: The formatted ISO 8601 string, or ``None`` if input is ``None``.
+    """
     return dt_format(dt, iso_format())
