@@ -26,14 +26,14 @@ class Attempt(object):
         last_exception: Exception,
     ):
         """
-        Represents an attempt in retrying
+        Represents an attempt in retrying.
 
-        :param number: attempt number
-        :param prev_wait: previous wait time
-        :param next_wait: next wait time
-        :param start_time: first attempt start time
-        :param check_time: this attempt check time
-        :param last_exception: exception happened in the last attempt
+        :param number: The attempt number (1-based).
+        :param prev_wait: The wait time before the previous attempt (in seconds).
+        :param next_wait: The wait time before the next attempt (in seconds).
+        :param start_time: The start time of the first attempt.
+        :param check_time: The time at which the current attempt is checked.
+        :param last_exception: The exception raised during the last attempt, if any.
         """
         self.number = number
         self.prev_wait = prev_wait
@@ -47,19 +47,25 @@ class Retry(abc.ABC):
     @abc.abstractmethod
     def on_attempt(self, attempt: Attempt):
         """
-        Updates the retry state on attempt
+        Called before each retry attempt. Can be used to perform custom logic or logging before an attempt is made.
 
-        :param attempt: attempt
+        :param attempt: The current ``Attempt`` instance containing attempt details.
         """
         pass
 
     @abc.abstractmethod
     def execute(self, *args, **kwargs):
+        """
+        Executes the target operation with retry logic. Must be implemented by subclasses.
+
+        :param args: Positional arguments for the operation.
+        :param kwargs: Keyword arguments for the operation.
+        :return: The result of the operation.
+        """
         pass
 
 
 class RetryWrapper(object):
-
     def __init__(
         self,
         cls,
@@ -72,16 +78,17 @@ class RetryWrapper(object):
         timeout: int = None,
     ):
         """
-        Retry executor
+        Retry executor that wraps a callable or ``Retry`` instance, providing flexible retry strategies including fixed,
+        exponential, and random waits.
 
-        :param cls: target callable
-        :param wait: fixed wait between retrials
-        :param wait_exponent_init: initial of exponentially increasing wait
-        :param wait_exponent_max: max of exponentially increasing wait
-        :param wait_random_min: min of random wait
-        :param wait_random_max: max of random wait
-        :param retrials: max retrials
-        :param timeout: timeout
+        :param cls: The target callable or ``Retry`` instance to execute.
+        :param wait: Fixed wait time (in seconds) between retrials.
+        :param wait_exponent_init: Initial wait time for exponential backoff.
+        :param wait_exponent_max: Maximum wait time for exponential backoff.
+        :param wait_random_min: Minimum wait time for random backoff.
+        :param wait_random_max: Maximum wait time for random backoff.
+        :param retrials: Maximum number of retrials (``None`` for unlimited).
+        :param timeout: Maximum total time (in seconds) allowed for all attempts (``None`` for unlimited).
         """
         self.__wrapped = cls
         self.wait = wait
@@ -93,9 +100,22 @@ class RetryWrapper(object):
         self.timeout = timeout
 
     def __call__(self, *args, **kwargs):
+        """
+        Invokes the wrapped callable or ``Retry`` instance with retry logic.
+
+        :param args: Positional arguments for the operation.
+        :param kwargs: Keyword arguments for the operation.
+        :return: The result of the operation.
+        """
         return self.__run(*args, **kwargs)
 
     def __next_wait(self, attempt_number: int):
+        """
+        Determines the wait time before the next retry attempt based on the configured strategy.
+
+        :param attempt_number: The current attempt number (1-based).
+        :return: The wait time in seconds, or ``None`` if not applicable.
+        """
         if attempt_number <= 0:
             return None
         elif self.wait is not None:
@@ -108,12 +128,27 @@ class RetryWrapper(object):
             return 0
 
     def __check_timeout(self, start_time: datetime.datetime):
+        """
+        Checks if the retry operation has exceeded the configured timeout.
+
+        :param start_time: The start time of the first attempt.
+        :return: Tuple (``True`` if within timeout, current time as ``datetime``).
+        """
         now = datetime.datetime.now()
         if self.timeout is None:
             return True, now
         return (now < start_time + datetime.timedelta(seconds=self.timeout)), now
 
     def __run(self, *args, **kwargs):
+        """
+        Runs the retry loop, invoking the wrapped callable or ``Retry`` instance until success, retrials exhausted, or
+        timeout reached.
+
+        :param args: Positional arguments for the operation.
+        :param kwargs: Keyword arguments for the operation.
+        :return: The result of the operation.
+        :raises RuntimeError: If all attempts fail or timeout is reached.
+        """
         attempt_number = 0
         start_time = datetime.datetime.now()
         last_exception = None
@@ -149,6 +184,15 @@ class RetryWrapper(object):
 
 
 def retry(wait: int = None, retrials: int = None, timeout: int = None):
+    """
+    Decorator to apply fixed wait retry logic to a function or callable.
+
+    :param wait: Fixed wait time (in seconds) between retrials.
+    :param retrials: Maximum number of retrials (``None`` for unlimited).
+    :param timeout: Maximum total time (in seconds) allowed for all attempts (``None`` for unlimited).
+    :return: A decorated function with retry logic.
+    """
+
     def wrapper(target):
         return RetryWrapper(target, wait=wait, retrials=retrials, timeout=timeout)
 
@@ -156,6 +200,16 @@ def retry(wait: int = None, retrials: int = None, timeout: int = None):
 
 
 def retry_exponent(wait_exponent_init: int, wait_exponent_max: int, retrials: int = None, timeout: int = None):
+    """
+    Decorator to apply exponential backoff retry logic to a function or callable.
+
+    :param wait_exponent_init: Initial wait time for exponential backoff.
+    :param wait_exponent_max: Maximum wait time for exponential backoff.
+    :param retrials: Maximum number of retrials (``None`` for unlimited).
+    :param timeout: Maximum total time (in seconds) allowed for all attempts (``None`` for unlimited).
+    :return: A decorated function with retry logic.
+    """
+
     def wrapper(target):
         return RetryWrapper(
             target,
@@ -169,6 +223,16 @@ def retry_exponent(wait_exponent_init: int, wait_exponent_max: int, retrials: in
 
 
 def retry_random(wait_random_min: int, wait_random_max: int, retrials: int = None, timeout: int = None):
+    """
+    Decorator to apply random wait retry logic to a function or callable.
+
+    :param wait_random_min: Minimum wait time for random backoff.
+    :param wait_random_max: Maximum wait time for random backoff.
+    :param retrials: Maximum number of retrials (``None`` for unlimited).
+    :param timeout: Maximum total time (in seconds) allowed for all attempts (``None`` for unlimited).
+    :return: A decorated function with retry logic.
+    """
+
     def wrapper(target):
         return RetryWrapper(
             target,
