@@ -40,13 +40,13 @@ def s3_make_client(
     endpoint_url: str = None,
 ) -> contextlib.AbstractContextManager[BaseClient]:
     """
-    Makes an AWS S3 client
+    Creates an AWS S3 client as a context manager for safe resource handling.
 
-    :param access_key_id: AWS access key id
-    :param secret_access_key: AWS secret access key
-    :param region_name: AWS service region name
-    :param endpoint_url: AWS service endpoint url
-    :return: context manager which wraps the AWS S3 client instance
+    :param access_key_id: AWS access key ID.
+    :param secret_access_key: AWS secret access key.
+    :param region_name: AWS service region name.
+    :param endpoint_url: AWS service endpoint URL.
+    :return: A context manager yielding an S3 client instance.
     """
     client = boto3.client("s3",
                           region_name=trim_to_none(region_name),
@@ -58,13 +58,13 @@ def s3_make_client(
 
 def s3_list_objects(client: BaseClient, bucket: str, prefix: str, limit: int = None) -> list[S3ObjectMeta]:
     """
-    Lists all objects from the given bucket and prefix
+    Lists all objects from the given S3 ``bucket`` and ``prefix``.
 
-    :param client: AWS S3 client instance
-    :param bucket: bucket name
-    :param prefix: object keys prefix
-    :param limit: maximum count of objects returns
-    :return: list of object meta items
+    :param client: AWS S3 client instance.
+    :param bucket: Bucket name.
+    :param prefix: Object keys prefix.
+    :param limit: Maximum number of objects to return (``None`` for all).
+    :return: List of ``S3ObjectMeta`` items.
     """
     entries = []
 
@@ -100,15 +100,15 @@ def s3_listfile(
     depth: int = 0,
 ) -> list[S3ObjectMeta]:
     """
-    Lists all objects from the given bucket and prefix
+    Lists all objects from the given S3 ``bucket`` and ``prefix``, filtered by patterns and directory depth.
 
-    :param client: AWS S3 client instance
-    :param bucket: bucket name
-    :param prefix: object keys prefix
-    :param include_patterns: inclusive glob patterns applied to the filenames
-    :param exclude_patterns: exclusive glob patterns applied to the filenames
-    :param depth: maximum depth of the subdirectories included in the scan
-    :return: list of object meta items
+    :param client: AWS S3 client instance.
+    :param bucket: Bucket name.
+    :param prefix: Object keys prefix.
+    :param include_patterns: Inclusive glob patterns applied to filenames.
+    :param exclude_patterns: Exclusive glob patterns applied to filenames.
+    :param depth: Maximum depth of subdirectories to include in the scan.
+    :return: List of ``S3ObjectMeta`` items.
     """
 
     # We add trailing slash "/" to the prefix if it is absent
@@ -129,24 +129,24 @@ def s3_listfile(
 
 def s3_cp_download(client: BaseClient, bucket: str, key: str, file_path: str):
     """
-    Downloads object from the given bucket and key to the given local file path
+    Downloads an object from the given S3 ``bucket`` and ``key`` to a local file path.
 
-    :param client: AWS S3 client instance
-    :param bucket: bucket name
-    :param key: object key
-    :param file_path: local file path
+    :param client: AWS S3 client instance.
+    :param bucket: Bucket name.
+    :param key: Object key.
+    :param file_path: Local file path to save the object.
     """
     client.download_file(bucket, key, file_path)
 
 
 def s3_cp_upload(client: BaseClient, file_path: str, bucket: str, key: str):
     """
-    Uploads object of the given local file path to the given bucket and key
+    Uploads a local file to the given S3 ``bucket`` and ``key``.
 
-    :param client: AWS S3 client instance
-    :param file_path: local file path
-    :param bucket: bucket name
-    :param key: object key
+    :param client: AWS S3 client instance.
+    :param file_path: Local file path to upload.
+    :param bucket: Bucket name.
+    :param key: Object key for the uploaded file.
     """
     t, _ = mimetypes.MimeTypes().guess_type(file_path)
     client.upload_file(file_path, bucket, key, ExtraArgs={"ContentType": "binary/octet-stream" if t is None else t})
@@ -164,16 +164,16 @@ def s3_sync_download(
     depth: int = 0,
 ):
     """
-    Recursively downloads all objects from the given bucket and prefix to the given local directory path
+    Recursively downloads all objects from the given S3 ``bucket`` and ``prefix`` to a local directory path, using a thread pool.
 
-    :param client: AWS S3 client instance
-    :param bucket: bucket name
-    :param prefix: object keys prefix
-    :param dir_path: local directory path
-    :param max_workers: number of maximum workers in thread pool
-    :param include_patterns: inclusive glob patterns applied to the filenames
-    :param exclude_patterns: exclusive glob patterns applied to the filenames
-    :param depth: maximum depth of the subdirectories included in the scan
+    :param client: AWS S3 client instance.
+    :param bucket: Bucket name.
+    :param prefix: Object keys prefix.
+    :param dir_path: Local directory path to save objects.
+    :param max_workers: Maximum number of worker threads.
+    :param include_patterns: Inclusive glob patterns applied to filenames.
+    :param exclude_patterns: Exclusive glob patterns applied to filenames.
+    :param depth: Maximum depth of subdirectories to include in the scan.
     """
 
     # We add trailing slash "/" to the prefix if it is absent
@@ -209,16 +209,16 @@ def s3_sync_upload(
     depth: int = 0,
 ):
     """
-    Recursively uploads all objects from the given local directory path to the given bucket and prefix
+    Recursively uploads all files from a local directory to the given S3 ``bucket`` and ``prefix``, using a thread pool.
 
-    :param client: AWS S3 client instance
-    :param dir_path: local directory
-    :param bucket: bucket name
-    :param prefix: object keys prefix
-    :param max_workers: number of maximum workers in thread pool
-    :param include_patterns: inclusive glob patterns applied to the filenames
-    :param exclude_patterns: exclusive glob patterns applied to the filenames
-    :param depth: maximum depth of the subdirectories included in the scan
+    :param client: AWS S3 client instance.
+    :param dir_path: Local directory path to upload from.
+    :param bucket: Bucket name.
+    :param prefix: Object keys prefix for uploaded files.
+    :param max_workers: Maximum number of worker threads.
+    :param include_patterns: Inclusive glob patterns applied to filenames.
+    :param exclude_patterns: Exclusive glob patterns applied to filenames.
+    :param depth: Maximum depth of subdirectories to include in the scan.
     """
 
     # We add trailing slash "/" to the prefix if it is absent
@@ -240,13 +240,13 @@ def s3_sync_upload(
 
 def s3_pull_text(client: BaseClient, bucket: str, key: str, encoding: str = None) -> str:
     """
-    Pulls text stored as object from the given bucket and key
+    Downloads and decodes text content stored as an object in the given S3 ``bucket`` and ``key``.
 
-    :param client: AWS S3 client instance
-    :param bucket: bucket name
-    :param key: key of the object storing the text
-    :param encoding: string encoding
-    :return: text content
+    :param client: AWS S3 client instance.
+    :param bucket: Bucket name.
+    :param key: Object key storing the text.
+    :param encoding: String encoding to use (defaults to UTF-8).
+    :return: The decoded text content.
     """
     with tempfile.TemporaryFile() as fp:
         client.download_fileobj(bucket, key, fp)
@@ -256,13 +256,13 @@ def s3_pull_text(client: BaseClient, bucket: str, key: str, encoding: str = None
 
 def s3_push_text(client: BaseClient, text: str, bucket: str, key: str, encoding: str = None):
     """
-    Pushes the given text to the object stored by the given bucket and key
+    Uploads the given text as an object to the specified S3 ``bucket`` and ``key``.
 
-    :param client: AWS S3 client instance
-    :param text: text content
-    :param bucket: bucket name
-    :param key: key of the object storing the text
-    :param encoding: string encoding
+    :param client: AWS S3 client instance.
+    :param text: Text content to upload.
+    :param bucket: Bucket name.
+    :param key: Object key to store the text.
+    :param encoding: String encoding to use (defaults to UTF-8).
     """
     with tempfile.TemporaryFile() as fp:
         fp.write(text.encode(encoding or "utf-8"))
