@@ -2,7 +2,7 @@ import unittest
 
 import ddt
 
-from iker.common.utils.dtutils import basic_format, extended_format, iso_format
+from iker.common.utils.dtutils import basic_format, extended_format, iso_format, td_from_us, td_to_us
 from iker.common.utils.dtutils import dt_format, dt_format_iso, dt_parse, dt_parse_iso
 from iker.common.utils.dtutils import dt_from_ts, dt_from_ts_us, dt_to_ts, dt_to_ts_us
 from iker.common.utils.dtutils import dt_utc
@@ -35,6 +35,24 @@ class DtUtilsTest(unittest.TestCase):
         self.assertEqual(dt_parse_iso("1970-01-01T00:00:00.000000+00:00"), dt_utc_epoch())
         self.assertEqual(dt_parse_iso("1970-01-01T00:00:00.000000"), dt_utc_epoch())
 
+    data_td_us_roundtrip = [
+        (0,),
+        (1,),
+        (999,),
+        (1000,),
+        (999999,),
+        (1000000,),
+        (60000000,),
+        (3600000000,),
+        (86400000000,),
+        (31536000000000,),
+    ]
+
+    @ddt.idata(data_td_us_roundtrip)
+    @ddt.unpack
+    def test_td_us_roundtrip(self, data):
+        self.assertEqual(data, td_to_us(td_from_us(data)))
+
     data_dt_to_ts = [
         (dt_utc(1970, 1, 1), 0.0),
         (dt_utc(1969, 12, 31, 23, 59, 59), -1.0),
