@@ -7,13 +7,14 @@ from iker.common.utils import retry
 
 @ddt.ddt
 class RetryTest(unittest.TestCase):
-
-    @ddt.data(
+    data_retry__ok = [
         ("dummy-content", 1, 0),
         ("dummy-content", 1, 3),
         ("Old MacDonald had a farm", 2, 4),
         ("Ee-i-ee-i-o", 1, 5),
-    )
+    ]
+
+    @ddt.idata(data_retry__ok)
     @ddt.unpack
     def test_retry__ok(self, content, wait, retrials):
         result = []
@@ -25,11 +26,13 @@ class RetryTest(unittest.TestCase):
         callee(content)
         self.assertEqual([content], result)
 
-    @ddt.data(
+    data_retry__with_timeout = [
         ("dummy-content", 5, 3, 10),
         ("Old MacDonald had a farm", 2, 4, 6),
         ("Ee-i-ee-i-o", 1, 5, 3),
-    )
+    ]
+
+    @ddt.idata(data_retry__with_timeout)
     @ddt.unpack
     def test_retry__with_timeout(self, content, wait, retrials, timeout):
         result = []
@@ -44,11 +47,13 @@ class RetryTest(unittest.TestCase):
 
         self.assertTrue(len(result) < retrials + 1)
 
-    @ddt.data(
+    data_retry__with_timeout_only = [
         ("dummy-content", 5, 10),
         ("Old MacDonald had a farm", 2, 6),
         ("Ee-i-ee-i-o", 1, 3),
-    )
+    ]
+
+    @ddt.idata(data_retry__with_timeout_only)
     @ddt.unpack
     def test_retry__with_timeout_only(self, content, wait, timeout):
         result = []
@@ -61,11 +66,13 @@ class RetryTest(unittest.TestCase):
         with self.assertRaises(RuntimeError):
             callee(content)
 
-    @ddt.data(
+    data_retry = [
         ("dummy-content", 1, 3),
         ("Old MacDonald had a farm", 2, 4),
         ("Ee-i-ee-i-o", 1, 5),
-    )
+    ]
+
+    @ddt.idata(data_retry)
     @ddt.unpack
     def test_retry(self, content, wait, retrials):
         result = []
@@ -80,11 +87,13 @@ class RetryTest(unittest.TestCase):
 
         self.assertEqual([content for _ in range(retrials + 1)], result)
 
-    @ddt.data(
+    data_retry__on_retry_instance = [
         ("dummy-content", 1, 3),
         ("Old MacDonald had a farm", 2, 4),
         ("Ee-i-ee-i-o", 1, 5),
-    )
+    ]
+
+    @ddt.idata(data_retry__on_retry_instance)
     @ddt.unpack
     def test_retry__on_retry_instance(self, content, wait, retrials):
         result = []
@@ -108,11 +117,13 @@ class RetryTest(unittest.TestCase):
         self.assertEqual([content for _ in range(retrials + 1)], result)
         self.assertTrue(all(a.next_wait == wait for a in callee.attempts))
 
-    @ddt.data(
+    data_retry_exponent = [
         ("dummy-content", 1, 4, 3),
         ("Old MacDonald had a farm", 2, 1, 4),
         ("Ee-i-ee-i-o", 1, 10, 5),
-    )
+    ]
+
+    @ddt.idata(data_retry_exponent)
     @ddt.unpack
     def test_retry_exponent(self, content, wait_exponent_init, wait_exponent_max, retrials):
         result = []
@@ -128,11 +139,13 @@ class RetryTest(unittest.TestCase):
 
         self.assertEqual([content for _ in range(retrials + 1)], result)
 
-    @ddt.data(
+    data_retry_exponent__on_retry_instance = [
         ("dummy-content", 1, 4, 3),
         ("Old MacDonald had a farm", 2, 1, 4),
         ("Ee-i-ee-i-o", 1, 10, 5),
-    )
+    ]
+
+    @ddt.idata(data_retry_exponent__on_retry_instance)
     @ddt.unpack
     def test_retry_exponent__on_retry_instance(self, content, wait_exponent_init, wait_exponent_max, retrials):
         result = []
@@ -157,11 +170,13 @@ class RetryTest(unittest.TestCase):
         self.assertTrue(all(
             a.next_wait == min(wait_exponent_init * (2 ** (a.number - 1)), wait_exponent_max) for a in callee.attempts))
 
-    @ddt.data(
+    data_retry_random = [
         ("dummy-content", 1, 4, 3),
         ("Old MacDonald had a farm", 2, 3, 4),
         ("Ee-i-ee-i-o", 1, 10, 5),
-    )
+    ]
+
+    @ddt.idata(data_retry_random)
     @ddt.unpack
     def test_retry_random(self, content, wait_random_min, wait_random_max, retrials):
         result = []
@@ -176,11 +191,13 @@ class RetryTest(unittest.TestCase):
 
         self.assertEqual([content for _ in range(retrials + 1)], result)
 
-    @ddt.data(
+    data_retry_random__on_retry_instance = [
         ("dummy-content", 1, 4, 3),
         ("Old MacDonald had a farm", 2, 3, 4),
         ("Ee-i-ee-i-o", 1, 10, 5),
-    )
+    ]
+
+    @ddt.idata(data_retry_random__on_retry_instance)
     @ddt.unpack
     def test_retry_random__on_retry_instance(self, content, wait_random_min, wait_random_max, retrials):
         result = []
