@@ -6,9 +6,8 @@ from typing import Self
 import ddt
 
 from iker.common.utils.sequtils import Seq
-from iker.common.utils.sequtils import batch_yield
+from iker.common.utils.sequtils import batched, deduped, flatten, grouped
 from iker.common.utils.sequtils import chunk, chunk_between, chunk_with_key, merge_chunks
-from iker.common.utils.sequtils import deduped, grouped
 from iker.common.utils.sequtils import head, last
 from iker.common.utils.sequtils import init, init_iter, tail, tail_iter
 from iker.common.utils.sequtils import seq
@@ -209,7 +208,7 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_grouped)
     @ddt.unpack
     def test_grouped(self, data, key_func, expect):
-        self.assertEqual(expect, grouped(data, key_func=key_func))
+        self.assertEqual(expect, list(grouped(data, key_func=key_func)))
 
     data_grouped__values_only = [
         (None, lambda x: x, []),
@@ -278,7 +277,7 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_grouped__values_only)
     @ddt.unpack
     def test_grouped__values_only(self, data, key_func, expect):
-        self.assertEqual(expect, grouped(data, key_func=key_func, values_only=True))
+        self.assertEqual(expect, list(grouped(data, key_func=key_func, values_only=True)))
 
     data_deduped = [
         (None, lambda x: x, []),
@@ -305,9 +304,9 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_deduped)
     @ddt.unpack
     def test_deduped(self, data, comp_func, expect):
-        self.assertEqual(expect, deduped(data, comp_func=comp_func))
+        self.assertEqual(expect, list(deduped(data, comp_func=comp_func)))
 
-    data_batch_yield = [
+    data_batched = [
         ([], 1, []),
         ([1], 1, [[1]]),
         ([1], 2, [[1]]),
@@ -318,10 +317,48 @@ class SeqUtilsTest(unittest.TestCase):
         ([[1, 2, 3], [4, 5, 6]], 2, [[[1, 2, 3], [4, 5, 6]]]),
     ]
 
-    @ddt.idata(data_batch_yield)
+    @ddt.idata(data_batched)
     @ddt.unpack
-    def test_batch_yield(self, data, batch_size, expect):
-        self.assertEqual(expect, list(batch_yield(data, batch_size)))
+    def test_batched(self, data, batch_size, expect):
+        self.assertEqual(expect, list(batched(data, batch_size)))
+
+    data_flatten = [
+        (None, []),
+        ([None], []),
+        ([[[None]]], []),
+        ([None, [None, [None, [None]]]], []),
+        (1, [1]),
+        ([], []),
+        ([1], [1]),
+        ([1, 2, 3], [1, 2, 3]),
+        ([[1, 2], [3, 4]], [1, 2, 3, 4]),
+        ([[[1]], [[2]], [[3]], [[4]]], [1, 2, 3, 4]),
+        ([[[1], [2]], [[3], [4]]], [1, 2, 3, 4]),
+        ([[], [], []], []),
+        ([[], [1], [], [2], [], [3], [], [4], []], [1, 2, 3, 4]),
+        ([1, [2], [[3]], [[[4]]]], [1, 2, 3, 4]),
+        ([1, [2, [3, [4]]]], [1, 2, 3, 4]),
+        ([[1, None, None, 2], [None, 3, 4, None]], [1, 2, 3, 4]),
+        ([1, [None, [2, [None, [3, [None, [4, [None]]]]]]]], [1, 2, 3, 4]),
+        ("foo", ["foo"]),
+        ([], []),
+        (["foo"], ["foo"]),
+        (["foo", "bar", "baz"], ["foo", "bar", "baz"]),
+        ([["foo", "bar"], ["baz", "qux"]], ["foo", "bar", "baz", "qux"]),
+        ([[["foo"]], [["bar"]], [["baz"]], [["qux"]]], ["foo", "bar", "baz", "qux"]),
+        ([[["foo"], ["bar"]], [["baz"], ["qux"]]], ["foo", "bar", "baz", "qux"]),
+        ([[], [], []], []),
+        ([[], ["foo"], [], ["bar"], [], ["baz"], [], ["qux"], []], ["foo", "bar", "baz", "qux"]),
+        (["foo", ["bar"], [["baz"]], [[["qux"]]]], ["foo", "bar", "baz", "qux"]),
+        (["foo", ["bar", ["baz", ["qux"]]]], ["foo", "bar", "baz", "qux"]),
+        ([["foo", None, None, "bar"], [None, "baz", "qux", None]], ["foo", "bar", "baz", "qux"]),
+        (["foo", [None, ["bar", [None, ["baz", [None, ["qux", [None]]]]]]]], ["foo", "bar", "baz", "qux"]),
+    ]
+
+    @ddt.idata(data_flatten)
+    @ddt.unpack
+    def test_flatten(self, data, expect):
+        self.assertEqual(expect, list(flatten(data)))
 
     data_chunk = [
         (None, lambda x: x, []),
@@ -405,7 +442,7 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_chunk)
     @ddt.unpack
     def test_chunk(self, data, chunk_func, expect):
-        self.assertEqual(expect, chunk(data, chunk_func=chunk_func))
+        self.assertEqual(expect, list(chunk(data, chunk_func=chunk_func)))
 
     data_chunk__exclusive_end = [
         (None, lambda x: x, []),
@@ -489,7 +526,7 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_chunk__exclusive_end)
     @ddt.unpack
     def test_chunk__exclusive_end(self, data, chunk_func, expect):
-        self.assertEqual(expect, chunk(data, chunk_func=chunk_func, exclusive_end=True))
+        self.assertEqual(expect, list(chunk(data, chunk_func=chunk_func, exclusive_end=True)))
 
     data_chunk_between = [
         (None, lambda x: x, []),
@@ -563,7 +600,7 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_chunk_between)
     @ddt.unpack
     def test_chunk_between(self, data, chunk_func, expect):
-        self.assertEqual(expect, chunk_between(data, chunk_func=chunk_func))
+        self.assertEqual(expect, list(chunk_between(data, chunk_func=chunk_func)))
 
     data_chunk_between__exclusive_end = [
         (None, lambda x: x, []),
@@ -637,7 +674,7 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_chunk_between__exclusive_end)
     @ddt.unpack
     def test_chunk_between__exclusive_end(self, data, chunk_func, expect):
-        self.assertEqual(expect, chunk_between(data, chunk_func=chunk_func, exclusive_end=True))
+        self.assertEqual(expect, list(chunk_between(data, chunk_func=chunk_func, exclusive_end=True)))
 
     data_chunk_with_key = [
         (None, lambda x: x, []),
@@ -711,7 +748,7 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_chunk_with_key)
     @ddt.unpack
     def test_chunk_with_key(self, data, key_func, expect):
-        self.assertEqual(expect, chunk_with_key(data, key_func=key_func))
+        self.assertEqual(expect, list(chunk_with_key(data, key_func=key_func)))
 
     data_chunk_with_key__exclusive_key = [
         (None, lambda x: x, []),
@@ -785,7 +822,7 @@ class SeqUtilsTest(unittest.TestCase):
     @ddt.idata(data_chunk_with_key__exclusive_key)
     @ddt.unpack
     def test_chunk_with_key__exclusive_key(self, data, key_func, expect):
-        self.assertEqual(expect, chunk_with_key(data, key_func=key_func, exclusive_end=True))
+        self.assertEqual(expect, list(chunk_with_key(data, key_func=key_func, exclusive_end=True)))
 
     data_merge_chunks = [
         (None, lambda x: x, []),
@@ -823,7 +860,7 @@ class SeqUtilsTest(unittest.TestCase):
                 [10, 11, 12, 13, 14],
                 [15, 16, 17, 18, 19],
             ],
-            lambda x, y: abs(head(x) - head(y)) < 10,
+            lambda x, y: head(x) % 10 == 0,
             [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9], [10, 11, 12, 13, 14, 15, 16, 17, 18, 19]],
         ),
         (
@@ -833,15 +870,15 @@ class SeqUtilsTest(unittest.TestCase):
                 [10, 11, 12, 13, 14],
                 [15, 16, 17, 18, 19],
             ],
-            lambda x, y: last(x) % 10 == 4,
-            [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9], [10, 11, 12, 13, 14, 15, 16, 17, 18, 19]],
+            lambda x, y: head(y) % 10 == 0,
+            [[0, 1, 2, 3, 4], [5, 6, 7, 8, 9, 10, 11, 12, 13, 14], [15, 16, 17, 18, 19]],
         ),
     ]
 
     @ddt.idata(data_merge_chunks)
     @ddt.unpack
     def test_merge_chunks(self, data, merge_func, expect):
-        self.assertEqual(expect, merge_chunks(data, merge_func=merge_func))
+        self.assertEqual(expect, list(merge_chunks(data, merge_func=merge_func)))
 
     data_merge_chunks__drop_exclusive_end = [
         (None, lambda x: x, []),
@@ -867,37 +904,37 @@ class SeqUtilsTest(unittest.TestCase):
                 [16, 17],
                 [17, 18],
                 [18, 19],
-                [19],
+                [19, 20],
             ],
             lambda x, y: True,
-            [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19]],
+            [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20]],
         ),
         (
             [
                 [0, 1, 2, 3, 4, 5],
                 [5, 6, 7, 8, 9, 10],
                 [10, 11, 12, 13, 14, 15],
-                [15, 16, 17, 18, 19],
+                [15, 16, 17, 18, 19, 20],
             ],
-            lambda x, y: abs(head(x) - head(y)) < 10,
-            [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10], [10, 11, 12, 13, 14, 15, 16, 17, 18, 19]],
+            lambda x, y: last(x) % 10 == 0,
+            [[0, 1, 2, 3, 4, 5], [5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15], [15, 16, 17, 18, 19, 20]],
         ),
         (
             [
                 [0, 1, 2, 3, 4, 5],
                 [5, 6, 7, 8, 9, 10],
                 [10, 11, 12, 13, 14, 15],
-                [15, 16, 17, 18, 19],
+                [15, 16, 17, 18, 19, 20],
             ],
-            lambda x, y: last(init(x)) % 10 == 4,
-            [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10], [10, 11, 12, 13, 14, 15, 16, 17, 18, 19]],
+            lambda x, y: last(y) % 10 == 0,
+            [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10], [10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20]],
         ),
     ]
 
     @ddt.idata(data_merge_chunks__drop_exclusive_end)
     @ddt.unpack
     def test_merge_chunks__drop_exclusive_end(self, data, merge_func, expect):
-        self.assertEqual(expect, merge_chunks(data, merge_func=merge_func, drop_exclusive_end=True))
+        self.assertEqual(expect, list(merge_chunks(data, merge_func=merge_func, drop_exclusive_end=True)))
 
 
 @dataclasses.dataclass(frozen=True, eq=True, order=True)
@@ -1071,6 +1108,106 @@ class SeqTest(unittest.TestCase):
         actual = seq(data).count_if(func)
         self.assertEqual(actual, expect)
 
+    data_pad_left = [
+        ([], 0, -1, []),
+        ([], -1, -1, []),
+        ([], 1, -1, [-1]),
+        ([], 5, -1, [-1, -1, -1, -1, -1]),
+        ([0], 0, -1, [0]),
+        ([0], -1, -1, [0]),
+        ([0], 1, -1, [-1, 0]),
+        ([0], 5, -1, [-1, -1, -1, -1, -1, 0]),
+        ([0, 0, 0], 0, -1, [0, 0, 0]),
+        ([0, 0, 0], -1, -1, [0, 0, 0]),
+        ([0, 0, 0], 1, -1, [-1, 0, 0, 0]),
+        ([0, 0, 0], 5, -1, [-1, -1, -1, -1, -1, 0, 0, 0]),
+        ([1, 2, 3, 4, 5], 0, -1, [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], -1, -1, [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 1, -1, [-1, 1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 5, -1, [-1, -1, -1, -1, -1, 1, 2, 3, 4, 5]),
+    ]
+
+    @ddt.idata(data_pad_left)
+    @ddt.unpack
+    def test_pad_left(self, data, n, value, expect):
+        actual = seq(data).pad_left(n, value)
+        self.assertEqual(actual.data, expect)
+
+    data_pad_right = [
+        ([], 0, -1, []),
+        ([], -1, -1, []),
+        ([], 1, -1, [-1]),
+        ([], 5, -1, [-1, -1, -1, -1, -1]),
+        ([0], 0, -1, [0]),
+        ([0], -1, -1, [0]),
+        ([0], 1, -1, [0, -1]),
+        ([0], 5, -1, [0, -1, -1, -1, -1, -1]),
+        ([0, 0, 0], 0, -1, [0, 0, 0]),
+        ([0, 0, 0], -1, -1, [0, 0, 0]),
+        ([0, 0, 0], 1, -1, [0, 0, 0, -1]),
+        ([0, 0, 0], 5, -1, [0, 0, 0, -1, -1, -1, -1, -1]),
+        ([1, 2, 3, 4, 5], 0, -1, [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], -1, -1, [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 1, -1, [1, 2, 3, 4, 5, -1]),
+        ([1, 2, 3, 4, 5], 5, -1, [1, 2, 3, 4, 5, -1, -1, -1, -1, -1]),
+    ]
+
+    @ddt.idata(data_pad_right)
+    @ddt.unpack
+    def test_pad_right(self, data, n, value, expect):
+        actual = seq(data).pad_right(n, value)
+        self.assertEqual(actual.data, expect)
+
+    data_pad_left_head = [
+        ([], 0, []),
+        ([], -1, []),
+        ([], 1, []),
+        ([], 5, []),
+        ([0], 0, [0]),
+        ([0], -1, [0]),
+        ([0], 1, [0, 0]),
+        ([0], 5, [0, 0, 0, 0, 0, 0]),
+        ([0, 0, 0], 0, [0, 0, 0]),
+        ([0, 0, 0], -1, [0, 0, 0]),
+        ([0, 0, 0], 1, [0, 0, 0, 0]),
+        ([0, 0, 0], 5, [0, 0, 0, 0, 0, 0, 0, 0]),
+        ([1, 2, 3, 4, 5], 0, [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], -1, [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 1, [1, 1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 5, [1, 1, 1, 1, 1, 1, 2, 3, 4, 5]),
+    ]
+
+    @ddt.idata(data_pad_left_head)
+    @ddt.unpack
+    def test_pad_left_head(self, data, n, expect):
+        actual = seq(data).pad_left_head(n)
+        self.assertEqual(actual.data, expect)
+
+    data_pad_right_last = [
+        ([], 0, []),
+        ([], -1, []),
+        ([], 1, []),
+        ([], 5, []),
+        ([0], 0, [0]),
+        ([0], -1, [0]),
+        ([0], 1, [0, 0]),
+        ([0], 5, [0, 0, 0, 0, 0, 0]),
+        ([0, 0, 0], 0, [0, 0, 0]),
+        ([0, 0, 0], -1, [0, 0, 0]),
+        ([0, 0, 0], 1, [0, 0, 0, 0]),
+        ([0, 0, 0], 5, [0, 0, 0, 0, 0, 0, 0, 0]),
+        ([1, 2, 3, 4, 5], 0, [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], -1, [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 1, [1, 2, 3, 4, 5, 5]),
+        ([1, 2, 3, 4, 5], 5, [1, 2, 3, 4, 5, 5, 5, 5, 5, 5]),
+    ]
+
+    @ddt.idata(data_pad_right_last)
+    @ddt.unpack
+    def test_pad_right_last(self, data, n, expect):
+        actual = seq(data).pad_right_last(n)
+        self.assertEqual(actual.data, expect)
+
     data_take_left = [
         ([], 0, []),
         ([], 1, []),
@@ -1155,11 +1292,11 @@ class SeqTest(unittest.TestCase):
         ([], 0, lambda x, y: x, []),
         ([], None, lambda x, y: x, []),
         ([0], 1, lambda x, y: x + y, [1]),
-        ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [16, 15, 13, 10, 6]),
-        ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [120, 120, 60, 20, 5]),
-        ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [54321, 5432, 543, 54, 5]),
-        (["1", "2", "3", "4", "5"], "", lambda x, y: x + y, ["54321", "5432", "543", "54", "5"]),
-        (["1", "2", "3", "4", "5"], "", lambda x, y: y + x, ["12345", "2345", "345", "45", "5"]),
+        ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [6, 10, 13, 15, 16]),
+        ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [5, 20, 60, 120, 120]),
+        ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [5, 54, 543, 5432, 54321]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: x + y, ["5", "54", "543", "5432", "54321"]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: y + x, ["5", "45", "345", "2345", "12345"]),
     ]
 
     @ddt.idata(data_scan_right)
@@ -1214,6 +1351,356 @@ class SeqTest(unittest.TestCase):
         actual = seq(data).fold_right(zero, func)
         self.assertEqual(actual.data, expect)
 
+    data_slide_left = [
+        ([], 0, lambda xs: sum(xs), []),
+        ([0], 2, lambda xs: sum(xs), []),
+        ([0], 1, lambda xs: sum(xs), [0]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), [6, 9, 12]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), [15]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), ["1", "2", "3", "4", "5"]),
+        (["1", "2", "3", "4", "5"], 3, lambda xs: "".join(xs), ["123", "234", "345"]),
+        (["1", "2", "3", "4", "5"], 5, lambda xs: "".join(xs), ["12345"]),
+    ]
+
+    @ddt.idata(data_slide_left)
+    @ddt.unpack
+    def test_slide_left(self, data, window, func, expect):
+        actual = seq(data).slide_left(window, func)
+        self.assertEqual(actual.data, expect)
+
+    data_slide_left__allow_partial = [
+        ([], 0, lambda xs: sum(xs), (True, True), []),
+        ([], 0, lambda xs: sum(xs), (True, False), []),
+        ([], 0, lambda xs: sum(xs), (False, True), []),
+        ([0], 2, lambda xs: sum(xs), (True, True), [0, 0]),
+        ([0], 2, lambda xs: sum(xs), (True, False), [0]),
+        ([0], 2, lambda xs: sum(xs), (False, True), [0]),
+        ([0], 1, lambda xs: sum(xs), (True, True), [0]),
+        ([0], 1, lambda xs: sum(xs), (True, False), [0]),
+        ([0], 1, lambda xs: sum(xs), (False, True), [0]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (True, True), [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (True, False), [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (False, True), [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (True, True), [1, 3, 6, 9, 12, 9, 5]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (True, False), [1, 3, 6, 9, 12]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (False, True), [6, 9, 12, 9, 5]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (True, True), [1, 3, 6, 10, 15, 14, 12, 9, 5]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (True, False), [1, 3, 6, 10, 15]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (False, True), [15, 14, 12, 9, 5]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (True, True), [1, 3, 6, 10, 15, 15, 15, 14, 12, 9, 5]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (True, False), [1, 3, 6, 10, 15]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (False, True), [15, 14, 12, 9, 5]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), (True, True), ["1", "2", "3", "4", "5"]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), (True, False), ["1", "2", "3", "4", "5"]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), (False, True), ["1", "2", "3", "4", "5"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         (True, True),
+         ["1", "12", "123", "234", "345", "45", "5"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         (True, False),
+         ["1", "12", "123", "234", "345"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         (False, True),
+         ["123", "234", "345", "45", "5"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         (True, True),
+         ["1", "12", "123", "1234", "12345", "2345", "345", "45", "5"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         (True, False),
+         ["1", "12", "123", "1234", "12345"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         (False, True),
+         ["12345", "2345", "345", "45", "5"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         (True, True),
+         ["1", "12", "123", "1234", "12345", "12345", "12345", "2345", "345", "45", "5"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         (True, False),
+         ["1", "12", "123", "1234", "12345"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         (False, True),
+         ["12345", "2345", "345", "45", "5"]),
+    ]
+
+    @ddt.idata(data_slide_left__allow_partial)
+    @ddt.unpack
+    def test_slide_left__allow_partial(self, data, window, func, allow_partial, expect):
+        actual = seq(data).slide_left(window, func, allow_partial=allow_partial)
+        self.assertEqual(actual.data, expect)
+
+    data_slide_left__padding = [
+        ([], 0, lambda xs: sum(xs), (1, -1), []),
+        ([], 0, lambda xs: sum(xs), (1, None), []),
+        ([], 0, lambda xs: sum(xs), (None, -1), []),
+        ([0], 2, lambda xs: sum(xs), (1, -1), [1, -1]),
+        ([0], 2, lambda xs: sum(xs), (1, None), [1, 0]),
+        ([0], 2, lambda xs: sum(xs), (None, -1), [0, -1]),
+        ([0], 1, lambda xs: sum(xs), (1, -1), [0]),
+        ([0], 1, lambda xs: sum(xs), (1, None), [0]),
+        ([0], 1, lambda xs: sum(xs), (None, -1), [0]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (1, 5), [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (1, None), [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (None, 5), [1, 2, 3, 4, 5]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (1, 5), [3, 4, 6, 9, 12, 14, 15]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (1, None), [3, 4, 6, 9, 12, 9, 5]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (None, 5), [1, 3, 6, 9, 12, 14, 15]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (1, 5), [5, 6, 8, 11, 15, 19, 22, 24, 25]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (1, None), [5, 6, 8, 11, 15, 14, 12, 9, 5]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (None, 5), [1, 3, 6, 10, 15, 19, 22, 24, 25]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (1, 5), [7, 8, 10, 13, 17, 21, 25, 29, 32, 34, 35]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (1, None), [7, 8, 10, 13, 17, 16, 15, 14, 12, 9, 5]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (None, 5), [1, 3, 6, 10, 15, 20, 25, 29, 32, 34, 35]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), ("(", ")"), ["1", "2", "3", "4", "5"]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), ("(", None), ["1", "2", "3", "4", "5"]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), (None, ")"), ["1", "2", "3", "4", "5"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         ("(", ")"),
+         ["((1", "(12", "123", "234", "345", "45)", "5))"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         ("(", None),
+         ["((1", "(12", "123", "234", "345", "45", "5"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         (None, ")"),
+         ["1", "12", "123", "234", "345", "45)", "5))"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         ("(", ")"),
+         ["((((1", "(((12", "((123", "(1234", "12345", "2345)", "345))", "45)))", "5))))"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         ("(", None),
+         ["((((1", "(((12", "((123", "(1234", "12345", "2345", "345", "45", "5"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         (None, ")"),
+         ["1", "12", "123", "1234", "12345", "2345)", "345))", "45)))", "5))))"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         ("(", ")"),
+         ["((((((1", "(((((12", "((((123", "(((1234", "((12345", "(12345)",
+          "12345))", "2345)))", "345))))", "45)))))", "5))))))"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         ("(", None),
+         ["((((((1", "(((((12", "((((123", "(((1234", "((12345", "(12345", "12345", "2345", "345", "45", "5"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         (None, ")"),
+         ["1", "12", "123", "1234", "12345", "12345)", "12345))", "2345)))", "345))))", "45)))))", "5))))))"]),
+    ]
+
+    @ddt.idata(data_slide_left__padding)
+    @ddt.unpack
+    def test_slide_left__padding(self, data, window, func, padding, expect):
+        actual = seq(data).slide_left(window, func, allow_partial=(True, True), padding=padding)
+        self.assertEqual(actual.data, expect)
+
+    data_slide_right = [
+        ([], 0, lambda xs: sum(xs), []),
+        ([0], 2, lambda xs: sum(xs), []),
+        ([0], 1, lambda xs: sum(xs), [0]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), [5, 4, 3, 2, 1]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), [12, 9, 6]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), [15]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), ["5", "4", "3", "2", "1"]),
+        (["1", "2", "3", "4", "5"], 3, lambda xs: "".join(xs), ["345", "234", "123"]),
+        (["1", "2", "3", "4", "5"], 5, lambda xs: "".join(xs), ["12345"]),
+    ]
+
+    @ddt.idata(data_slide_right)
+    @ddt.unpack
+    def test_slide_right(self, data, window, func, expect):
+        actual = seq(data).slide_right(window, func)
+        self.assertEqual(actual.data, expect)
+
+    data_slide_right__allow_partial = [
+        ([], 0, lambda xs: sum(xs), (True, True), []),
+        ([], 0, lambda xs: sum(xs), (True, False), []),
+        ([], 0, lambda xs: sum(xs), (False, True), []),
+        ([0], 2, lambda xs: sum(xs), (True, True), [0, 0]),
+        ([0], 2, lambda xs: sum(xs), (True, False), [0]),
+        ([0], 2, lambda xs: sum(xs), (False, True), [0]),
+        ([0], 1, lambda xs: sum(xs), (True, True), [0]),
+        ([0], 1, lambda xs: sum(xs), (True, False), [0]),
+        ([0], 1, lambda xs: sum(xs), (False, True), [0]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (True, True), [5, 4, 3, 2, 1]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (True, False), [5, 4, 3, 2, 1]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (False, True), [5, 4, 3, 2, 1]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (True, True), [5, 9, 12, 9, 6, 3, 1]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (True, False), [12, 9, 6, 3, 1]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (False, True), [5, 9, 12, 9, 6]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (True, True), [5, 9, 12, 14, 15, 10, 6, 3, 1]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (True, False), [15, 10, 6, 3, 1]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (False, True), [5, 9, 12, 14, 15]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (True, True), [5, 9, 12, 14, 15, 15, 15, 10, 6, 3, 1]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (True, False), [15, 10, 6, 3, 1]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (False, True), [5, 9, 12, 14, 15]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), (True, True), ["5", "4", "3", "2", "1"]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), (True, False), ["5", "4", "3", "2", "1"]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), (False, True), ["5", "4", "3", "2", "1"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         (True, True),
+         ["5", "45", "345", "234", "123", "12", "1"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         (True, False),
+         ["345", "234", "123", "12", "1"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         (False, True),
+         ["5", "45", "345", "234", "123"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         (True, True),
+         ["5", "45", "345", "2345", "12345", "1234", "123", "12", "1"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         (True, False),
+         ["12345", "1234", "123", "12", "1"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         (False, True),
+         ["5", "45", "345", "2345", "12345"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         (True, True),
+         ["5", "45", "345", "2345", "12345", "12345", "12345", "1234", "123", "12", "1"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         (True, False),
+         ["12345", "1234", "123", "12", "1"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         (False, True),
+         ["5", "45", "345", "2345", "12345"]),
+    ]
+
+    @ddt.idata(data_slide_right__allow_partial)
+    @ddt.unpack
+    def test_slide_right__allow_partial(self, data, window, func, allow_partial, expect):
+        actual = seq(data).slide_right(window, func, allow_partial=allow_partial)
+        self.assertEqual(actual.data, expect)
+
+    data_slide_right__padding = [
+        ([], 0, lambda xs: sum(xs), (1, -1), []),
+        ([], 0, lambda xs: sum(xs), (1, None), []),
+        ([], 0, lambda xs: sum(xs), (None, -1), []),
+        ([0], 2, lambda xs: sum(xs), (1, -1), [-1, 1]),
+        ([0], 2, lambda xs: sum(xs), (1, None), [0, 1]),
+        ([0], 2, lambda xs: sum(xs), (None, -1), [-1, 0]),
+        ([0], 1, lambda xs: sum(xs), (1, -1), [0]),
+        ([0], 1, lambda xs: sum(xs), (1, None), [0]),
+        ([0], 1, lambda xs: sum(xs), (None, -1), [0]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (1, 5), [5, 4, 3, 2, 1]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (1, None), [5, 4, 3, 2, 1]),
+        ([1, 2, 3, 4, 5], 1, lambda xs: sum(xs), (None, 5), [5, 4, 3, 2, 1]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (1, 5), [15, 14, 12, 9, 6, 4, 3]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (1, None), [5, 9, 12, 9, 6, 4, 3]),
+        ([1, 2, 3, 4, 5], 3, lambda xs: sum(xs), (None, 5), [15, 14, 12, 9, 6, 3, 1]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (1, 5), [25, 24, 22, 19, 15, 11, 8, 6, 5]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (1, None), [5, 9, 12, 14, 15, 11, 8, 6, 5]),
+        ([1, 2, 3, 4, 5], 5, lambda xs: sum(xs), (None, 5), [25, 24, 22, 19, 15, 10, 6, 3, 1]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (1, 5), [35, 34, 32, 29, 25, 21, 17, 13, 10, 8, 7]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (1, None), [5, 9, 12, 14, 15, 16, 17, 13, 10, 8, 7]),
+        ([1, 2, 3, 4, 5], 7, lambda xs: sum(xs), (None, 5), [35, 34, 32, 29, 25, 20, 15, 10, 6, 3, 1]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), ("(", ")"), ["5", "4", "3", "2", "1"]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), ("(", None), ["5", "4", "3", "2", "1"]),
+        (["1", "2", "3", "4", "5"], 1, lambda xs: "".join(xs), (None, ")"), ["5", "4", "3", "2", "1"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         ("(", ")"),
+         ["5))", "45)", "345", "234", "123", "(12", "((1"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         ("(", None),
+         ["5", "45", "345", "234", "123", "(12", "((1"]),
+        (["1", "2", "3", "4", "5"],
+         3,
+         lambda xs: "".join(xs),
+         (None, ")"),
+         ["5))", "45)", "345", "234", "123", "12", "1"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         ("(", ")"),
+         ["5))))", "45)))", "345))", "2345)", "12345", "(1234", "((123", "(((12", "((((1"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         ("(", None),
+         ["5", "45", "345", "2345", "12345", "(1234", "((123", "(((12", "((((1"]),
+        (["1", "2", "3", "4", "5"],
+         5,
+         lambda xs: "".join(xs),
+         (None, ")"),
+         ["5))))", "45)))", "345))", "2345)", "12345", "1234", "123", "12", "1"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         ("(", ")"),
+         ["5))))))", "45)))))", "345))))", "2345)))", "12345))", "(12345)",
+          "((12345", "(((1234", "((((123", "(((((12", "((((((1"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         ("(", None),
+         ["5", "45", "345", "2345", "12345", "(12345", "((12345", "(((1234", "((((123", "(((((12", "((((((1"]),
+        (["1", "2", "3", "4", "5"],
+         7,
+         lambda xs: "".join(xs),
+         (None, ")"),
+         ["5))))))", "45)))))", "345))))", "2345)))", "12345))", "12345)", "12345", "1234", "123", "12", "1"]),
+    ]
+
+    @ddt.idata(data_slide_right__padding)
+    @ddt.unpack
+    def test_slide_right__padding(self, data, window, func, padding, expect):
+        actual = seq(data).slide_right(window, func, allow_partial=(True, True), padding=padding)
+        self.assertEqual(actual.data, expect)
+
     data_reduce = [
         ([], lambda x, y: x, []),
         ([0], lambda x, y: x + y, [0]),
