@@ -18,8 +18,7 @@ home_dir = pathlib.Path.home
 
 @ddt.ddt
 class ShUtilsTest(unittest.TestCase):
-
-    @ddt.data(
+    data_extension = [
         (".", ""),
         ("..", ""),
         ("...", ""),
@@ -43,12 +42,14 @@ class ShUtilsTest(unittest.TestCase):
         ("/foo/bar/git.scrappy.ignored..baz.", "."),
         ("http://domain/foo/bar/git.scrappy.ignored", ".ignored"),
         ("s3://bucket/foo/bar/git.scrappy.ignored", ".ignored"),
-    )
+    ]
+
+    @ddt.idata(data_extension)
     @ddt.unpack
     def test_extension(self, data, expect):
         self.assertEqual(expect, extension(data))
 
-    @ddt.data(
+    data_stem = [
         (".", "."),
         ("..", ".."),
         ("...", "..."),
@@ -72,12 +73,14 @@ class ShUtilsTest(unittest.TestCase):
         ("/foo/bar/git.scrappy.ignored..baz.", "git.scrappy.ignored..baz"),
         ("http://domain/foo/bar/git.scrappy.ignored", "git.scrappy"),
         ("s3://bucket/foo/bar/git.scrappy.ignored", "git.scrappy"),
-    )
+    ]
+
+    @ddt.idata(data_stem)
     @ddt.unpack
     def test_stem(self, data, expect):
         self.assertEqual(expect, stem(data))
 
-    @ddt.data(
+    data_stem__minimal = [
         (".", "."),
         ("..", ".."),
         ("...", "..."),
@@ -101,12 +104,14 @@ class ShUtilsTest(unittest.TestCase):
         ("/foo/bar/git.scrappy.ignored..baz.", "git"),
         ("http://domain/foo/bar/git.scrappy.ignored", "git"),
         ("s3://bucket/foo/bar/git.scrappy.ignored", "git"),
-    )
+    ]
+
+    @ddt.idata(data_stem__minimal)
     @ddt.unpack
     def test_stem__minimal(self, data, expect):
         self.assertEqual(expect, stem(data, minimal=True))
 
-    @ddt.data(
+    data_extensions = [
         (".", []),
         ("..", []),
         ("...", []),
@@ -130,12 +135,14 @@ class ShUtilsTest(unittest.TestCase):
         ("/foo/bar/git.scrappy.ignored..baz.", [".", ".baz.", "..baz.", ".ignored..baz.", ".scrappy.ignored..baz."]),
         ("http://domain/foo/bar/git.scrappy.ignored", [".ignored", ".scrappy.ignored"]),
         ("s3://bucket/foo/bar/git.scrappy.ignored", [".ignored", ".scrappy.ignored"]),
-    )
+    ]
+
+    @ddt.idata(data_extensions)
     @ddt.unpack
     def test_extensions(self, data, expect):
         self.assertEqual(expect, extensions(data))
 
-    @ddt.data(
+    data_expanded_path = [
         (".", f"{work_dir()}"),
         ("./", f"{work_dir()}"),
         ("./foo", f"{work_dir()}/foo"),
@@ -178,14 +185,16 @@ class ShUtilsTest(unittest.TestCase):
         ("${EMPTY_ENV_PARAM}/foo/..", f"/"),
         ("${EMPTY_ENV_PARAM}/foo/../bar", f"/bar"),
         ("${EMPTY_ENV_PARAM}/foo/../bar/..", f"/"),
-    )
+    ]
+
+    @ddt.idata(data_expanded_path)
     @ddt.unpack
     def test_expanded_path(self, data, expect):
         os.environ["DUMMY_ENV_PARAM"] = "dummy_parent"
         os.environ["EMPTY_ENV_PARAM"] = ""
         self.assertEqual(norm_path(expect), norm_path(expanded_path(data)))
 
-    @ddt.data(
+    data_path_depth = [
         (".", ".", 0),
         ("..", "..", 0),
         ("/..", "/", 0),
@@ -209,12 +218,14 @@ class ShUtilsTest(unittest.TestCase):
 
         ("foo", "bar", -1),
         ("foo/bar", "foo/baz", -1),
-    )
+    ]
+
+    @ddt.idata(data_path_depth)
     @ddt.unpack
     def test_path_depth(self, root, child, expect):
         self.assertEqual(path_depth(root, child), expect)
 
-    @ddt.data(
+    data_glob_match = [
         (
             ["file.foo", "file.bar", "file.baz", "file.foo.bar", "file.foo.baz", "file.bar.baz", "file.foo.bar.baz"],
             ["*.foo", "*.bar"],
@@ -257,13 +268,15 @@ class ShUtilsTest(unittest.TestCase):
             [".foo"],
             ["file.foo", "file.bar", "file.baz", "file.foo.bar", "file.foo.baz", "file.bar.baz", "file.foo.bar.baz"],
         ),
-    )
+    ]
+
+    @ddt.idata(data_glob_match)
     @ddt.unpack
     def test_glob_match(self, names, include_patterns, exclude_patterns, expect):
         self.assertSetEqual(set(map(norm_path, glob_match(names, include_patterns, exclude_patterns))),
                             set(map(norm_path, expect)))
 
-    @ddt.data(
+    data_listfile = [
         (
             "{res_dir}/unittest/shutils",
             [],
@@ -397,7 +410,9 @@ class ShUtilsTest(unittest.TestCase):
             0,
             [],
         ),
-    )
+    ]
+
+    @ddt.idata(data_listfile)
     @ddt.unpack
     def test_listfile(self, path, include_patterns, exclude_patterns, depth, expect):
         self.assertSetEqual(set(map(norm_path, listfile(path.format(res_dir=resources_directory),
@@ -406,7 +421,7 @@ class ShUtilsTest(unittest.TestCase):
                                                         depth=depth))),
                             set(map(norm_path, map(lambda x: x.format(res_dir=resources_directory), expect))))
 
-    @ddt.data(
+    data_copy = [
         (
             "{res_dir}/unittest/shutils",
             "{tmp_dir}/unittest/shutils",
@@ -552,7 +567,9 @@ class ShUtilsTest(unittest.TestCase):
             0,
             [],
         ),
-    )
+    ]
+
+    @ddt.idata(data_copy)
     @ddt.unpack
     def test_copy(self, src, dst, include_patterns, exclude_patterns, depth, expect):
         with tempfile.TemporaryDirectory() as temp_directory:
